@@ -40,7 +40,16 @@ int plpgsql_check_mode = PLPGSQL_CHECK_MODE_BY_FUNCTION;
 
 typedef struct plpgsql_hashent
 {
+#if PG_VERSION_NUM >= 180000
+
+	CachedFunctionHashKey key;
+
+#else
+
 	PLpgSQL_func_hashkey key;
+
+#endif
+
 	TransactionId fn_xmin;
 	ItemPointerData fn_tid;
 	bool is_checked;
@@ -210,8 +219,16 @@ plpgsql_check_function_internal(plpgsql_check_result_info *ri,
 			 * Mark the function as busy, ensure higher than zero usage. There is no
 			 * reason for protection function against delete, but I afraid of asserts.
 			 */
+#if PG_VERSION_NUM >= 180000
+
+			function->cfunc.use_count++;
+
+#else
+
 			function->use_count++;
 
+#endif
+
 			/* Create a fake runtime environment and process check */
 			switch (cinfo->trigtype)
 			{
@@ -229,7 +246,16 @@ plpgsql_check_function_internal(plpgsql_check_result_info *ri,
 			}
 
 			function->cur_estate = cur_estate;
+
+#if PG_VERSION_NUM >= 180000
+
+			function->cfunc.use_count--;
+
+#else
+
 			function->use_count--;
+
+#endif
 		}
 		else
 			elog(NOTICE, "plpgsql_check is disabled");
@@ -268,7 +294,17 @@ plpgsql_check_function_internal(plpgsql_check_result_info *ri,
 		if (function)
 		{
 			function->cur_estate = cur_estate;
+
+#if PG_VERSION_NUM >= 180000
+
+			function->cfunc.use_count--;
+
+#else
+
 			function->use_count--;
+
+#endif
+
 			release_exprs(cstate.exprs);
 		}
 
@@ -1320,7 +1356,17 @@ plpgsql_check_HashTableInit(void)
 	Assert(plpgsql_check_HashTable == NULL);
 
 	memset(&ctl, 0, sizeof(ctl));
+
+#if PG_VERSION_NUM >= 180000
+
+	ctl.keysize = sizeof(CachedFunctionHashKey);
+
+#else
+
 	ctl.keysize = sizeof(PLpgSQL_func_hashkey);
+
+#endif
+
 	ctl.entrysize = sizeof(plpgsql_check_HashEnt);
 	plpgsql_check_HashTable = hash_create("plpgsql_check function cache",
 									FUNCS_PER_USER,
@@ -1337,6 +1383,22 @@ plpgsql_check_is_checked(PLpgSQL_function *func)
 {
 	plpgsql_check_HashEnt *hentry;
 
+#if PG_VERSION_NUM >= 180000
+
+	if (!func->cfunc.fn_hashkey)
+		return false;
+
+	hentry = (plpgsql_check_HashEnt *) hash_search(plpgsql_check_HashTable,
+											 (void *) func->cfunc.fn_hashkey,
+											 HASH_FIND,
+											 NULL);
+
+	if (hentry != NULL && hentry->fn_xmin == func->cfunc.fn_xmin &&
+			  ItemPointerEquals(&hentry->fn_tid, &func->cfunc.fn_tid))
+		return hentry->is_checked;
+
+#else
+
 	if (!func->fn_hashkey)
 		return false;
 
@@ -1349,6 +1411,8 @@ plpgsql_check_is_checked(PLpgSQL_function *func)
 			  ItemPointerEquals(&hentry->fn_tid, &func->fn_tid))
 		return hentry->is_checked;
 
+#endif
+
 	return false;
 }
 
@@ -1365,6 +1429,18 @@ plpgsql_check_mark_as_checked(PLpgSQL_function *func)
 		plpgsql_check_HashEnt *hentry;
 		bool		found;
 
+#if PG_VERSION_NUM >= 180000
+
+		hentry = (plpgsql_check_HashEnt *) hash_search(plpgsql_check_HashTable,
+												 (void *) func->cfunc.fn_hashkey,
+												 HASH_ENTER,
+												 &found);
+
+		hentry->fn_xmin = func->cfunc.fn_xmin;
+		hentry->fn_tid = func->cfunc.fn_tid;
+
+#else
+
 		hentry = (plpgsql_check_HashEnt *) hash_search(plpgsql_check_HashTable,
 												 (void *) func->fn_hashkey,
 												 HASH_ENTER,
@@ -1373,6 +1449,7 @@ plpgsql_check_mark_as_checked(PLpgSQL_function *func)
 		hentry->fn_xmin = func->fn_xmin;
 		hentry->fn_tid = func->fn_tid;
 
+#endif
 		hentry->is_checked = true;
 	}
 }
