@@ -244,8 +244,19 @@ func_info_init_hashkey(func_info_hashkey *hk, PLpgSQL_function *func)
 	memset(hk, 0, sizeof(func_info_hashkey));
 
 	hk->fn_oid = func->fn_oid;
+
+#if PG_VERSION_NUM >= 180000
+
+	hk->fn_xmin = func->cfunc.fn_xmin;
+	hk->fn_tid = func->cfunc.fn_tid;
+
+#else
+
 	hk->fn_xmin = func->fn_xmin;
 	hk->fn_tid = func->fn_tid;
+
+#endif
+
 }
 
 /*
